package MyPhrasebook;

use strict;
use warnings;

use base qw( Data::Phrasebook );

1;
